@@ -10,6 +10,8 @@ MAX_CHAR_RANDOM_UUID4                           = 20
 PAGINATION_SIZE                                 = 2
 VISIBLE_PAGE_COUNT                              = 10
 
+DEFAULT_GMT_HOURS                               = 8
+
 GENDER_MALE_CODE                                = 'm'
 GENDER_FEMALE_CODE                              = 'f'
 
@@ -21,4 +23,7 @@ DATASTORE_SERVICE_ACCOUNT_KEY_FILEPATH          = os.environ['SERVICE_ACCOUNT_KE
 
 DATASTORE_CREDENTIAL_PATH                       = os.path.abspath(os.path.dirname(config_path.__file__)) + '/' + DATASTORE_SERVICE_ACCOUNT_KEY_FILEPATH
 
-MERCHANT_STAT_FIGURE_UPDATE_INTERVAL_IN_MINUTES = os.environ['MERCHANT_STAT_FIGURE_UPDATE_INTERVAL_IN_MINUTES']
\ No newline at end of file
+MERCHANT_STAT_FIGURE_UPDATE_INTERVAL_IN_MINUTES = os.environ['MERCHANT_STAT_FIGURE_UPDATE_INTERVAL_IN_MINUTES']
+
+HANDLE_DATETIME_WITH_GMT                        = os.environ.get('HANDLE_DATETIME_WITH_GMT')
+SERVER_DATETIME_GMT                             = os.environ.get('SERVER_DATETIME_GMT')
\ No newline at end of file
